.. include:: links.rst

Installation
============

Gradec can be installed from pip. To install the latest official release:

.. code-block:: bash

    pip install gradec

If you want to use the most up-to-date version, you can install from the ``main`` branch:

.. code-block:: bash

    pip install git+https://github.com/JulioAPeraza/gradec.git

Gradec requires Python ``>=3.8`` and a number of packages.
For a complete list, please see ``gradec/pyproject.toml``.

.. note::
    We only support Python versions that are part of the Python release cycle (i.e., 3.8, 3.9, 
    3.10, and 3.11). For more information, see `Python Supported Versions`_.

What Next?
----------

For an overview of what you can do with Gradec see `Gradec Documentation`_.

If you have questions, or need help with using Gradec, check out `NeuroStars`_.
